pub enum Layer {
Linear(AffFunc),
ReLU(usize),
LeakyReLU(usize, f64),
HardTanh(usize),
HardSigmoid(usize),
Argmax,
ClassChar(usize),
}Expand description
A simple enum type to conveniently specify the layer structure of a neural network.
Each Layer corresponds to one piece-wise linear function.
Variants
Linear(AffFunc)
A fully connected linear layer
ReLU(usize)
The ReLU applied to the i-th component of the input
LeakyReLU(usize, f64)
The Leaky ReLU applied to the i-th component of the input
HardTanh(usize)
The hard hyperbolic tangent applied to the i-th component of the input
HardSigmoid(usize)
The hard sigmoid applied to the i-th component of the input
Argmax
The argmax function
ClassChar(usize)
A binary version of the argmax called class characterization. The result is a boolean indicating whether the input belongs to the specified class or not.