pub fn read_layers<P: AsRef<Path>>(path: &P) -> Result<Vec<Layer>, ReadNpzError>Expand description
Parses numpy’s “npz” file format and returns the contained layers.
Affinitree supports a dialect based on numpy’s “npz” format to encode the layers of a piece-wise linear neural network. The structure is significantly simpler than other formats such as “onnx”.
The underlying format from numpy is easy to use. It is described at https://numpy.org/doc/stable/reference/generated/numpy.lib.format.html