Module iter

Module iter 

Graph iterators for trees

Structs

Bfs
A breath-first traversal for Tree.
DfsEdge
A depth-first traversal for Tree returning the current edge instead of the node.
DfsNodeData
A collection of information provided by depth-first traversal of graphs.
DfsPre
A depth-first traversal for Tree.
EdgeData
Representation of an edge in Tree.
TraversalIter
A wrapper of TraversalMut that implements the iterator interface by borrowing the underlying tree. As such, the iterator keeps an active reference to the tree, which prevents mutual access to the tree during iteration.

Traits

TraversalMut
Traverses the specified tree.