pub struct Bfs {
pub size_lb: usize,
pub size_ub: usize,
/* private fields */
}Expand description
A breath-first traversal for Tree.
Fields
size_lb: usizesize_ub: usizeTrait Implementations
Sourceimpl TraversalMut for Bfs
impl TraversalMut for Bfs
type Item = DfsNodeData
Sourcefn new<N, const K: usize>(tree: &Tree<N, K>, root: TreeIndex) -> Bfs
fn new<N, const K: usize>(tree: &Tree<N, K>, root: TreeIndex) -> Bfs
Creates a new traversal over the given
tree starting at the given root.Sourcefn skip_subtree(&mut self)
fn skip_subtree(&mut self)
Alters the iteration such that the subtree of the current node is skipped.
Sourcefn next<N, const K: usize>(&mut self, tree: &Tree<N, K>) -> Option<DfsNodeData>
fn next<N, const K: usize>(&mut self, tree: &Tree<N, K>) -> Option<DfsNodeData>
Returns the next node in this traversal together with the nodes’s depth in the tree, or None if the traversal is done. Read more