Graph iterators for trees
Structs
- Bfs
- A breath-first traversal for
Tree. - DfsEdge
- A depth-first traversal for
Treereturning the current edge instead of the node. - DfsNode
Data - A collection of information provided by depth-first traversal of graphs.
- DfsPre
- A depth-first traversal for
Tree. - Edge
Data - Representation of an edge in
Tree. - Traversal
Iter - A wrapper of
TraversalMutthat implements the iterator interface by borrowing the underlying tree. As such, the iterator keeps an active reference to the tree, which prevents mutual access to the tree during iteration.
Traits
- Traversal
Mut - Traverses the specified tree.